# 🔬 &nbsp;TUM ESM Python Utilities

**Install the Python library with:**

```bash
poetry add tum_esm_utils
# or
pip install tum_esm_utils
```

<br/>

## For Developers

**Publish the Package to PyPI:**

```bash
poetry build
poetry publish
```

**Serve documentation page:**

```bash
docsify serve ./docs
```
